@@ -417,7 +417,8 @@ FUNC (generate_ualphabet) (text_fuzzy_t * tf)
     /* Create a zeroed alphabet. */
 
     u->alphabet = calloc (u->size, sizeof (char));
-    FAIL (! u->alphabet, memory_error);
+    FAIL_MSG (! u->alphabet, memory_error, "Could not allocate %d memory slots",
+	      u->size);
 
     tf->n_mallocs++;
 
